def skf(results, keyword):   
	
	'''Safe Key Finder: recebe um dicionario e uma key, ou lista
	para encontrar de forma encadeada, quando convertido do json e 
	procura de forma tolerante a erros, devolve str nula se nao encontra'''
	
	for i_key in keyword:
		if isinstance(results, dict):
			if results.has_key(i_key):
				results = results[i_key]			
			else:
				return ''
		elif isinstance(results, list) and isinstance(i_key, int):
			if len(results)>i_key:
				results = results[i_key]
			else:
				return ''
		else:
			return ''
	return results


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="skf", # Replace with your own username
    version="0.0.1",
    author="Rodrigo Francisco Sacht",
    author_email="rodrigofsacht@gmail.com",
    description="Safe Key Find in dict",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/rodrigofsacht/skf",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.3',
)